--  dh_ada_library, helper for Ada libraries Debian maintainers
--
--  Copyright (C) 2012-2013 Nicolas Boulenguez <nicolas@debian.org>
--
--  This program is free software: you can redistribute it and/or
--  modify it under the terms of the GNU General Public License as
--  published by the Free Software Foundation, either version 3 of the
--  License, or (at your option) any later version.
--  This program is distributed in the hope that it will be useful, but
--  WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
--  General Public License for more details.
--  You should have received a copy of the GNU General Public License
--  along with this program. If not, see <http://www.gnu.org/licenses/>.
--
private with Ada.Containers.Indefinite_Ordered_Maps;

package Environment_Variable_Backups is

   --  An ugly trick to transmit scenario variables because the
   --  current version of Prj does not allow to transmit scenario
   --  variables easily. We set environment variables, load the file
   --  then reset them. Here are the structures used to store the old
   --  state.

   --  This package should be replaced as soon as possible with Prj
   --  options.

   pragma Elaborate_Body;

   type Backup is private;
   --  Only changes done with Set are stored and reverted.

   procedure Set (Name      : in     String;
                  New_Value : in     String;
                  Changes   : in out Backup);

   procedure Restore (Changes : in Backup);

private

   type Variable_State
     (Was_Set      : Boolean;
      Value_Length : Natural) is record
      case Was_Set is
         when True => Value : String (1 .. Value_Length);
         when False => null;
      end case;
   end record;

   pragma Warnings (Off,
                    "pragma Warnings Off for ""*"" unused, could be omitted");

   package Variable_Maps is new Ada.Containers.Indefinite_Ordered_Maps
     (String, Variable_State);

   pragma Warnings (On,
                    "pragma Warnings Off for ""*"" unused, could be omitted");

   type Backup is new Variable_Maps.Map with null record;

end Environment_Variable_Backups;
